#
# spec file for package qore-json-module
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_ver 1.8.2

%{?_datarootdir: %global mydatarootdir %_datarootdir}
%{!?_datarootdir: %global mydatarootdir /usr/share}

%define module_api %(qore --latest-module-api 2>/dev/null)
%define module_dir %{_libdir}/qore-modules
%global user_module_dir %{mydatarootdir}/qore-modules/

%if 0%{?sles_version}

%define dist .sles%{?sles_version}

%else
%if 0%{?suse_version}

# get *suse release major version
%define os_maj %(echo %suse_version|rev|cut -b3-|rev)
# get *suse release minor version without trailing zeros
%define os_min %(echo %suse_version|rev|cut -b-2|rev|sed s/0*$//)

%if %suse_version
%define dist .opensuse%{os_maj}_%{os_min}
%endif

%endif
%endif

# see if we can determine the distribution type
%if 0%{!?dist:1}
%define rh_dist %(if [ -f /etc/redhat-release ];then cat /etc/redhat-release|sed "s/[^0-9.]*//"|cut -f1 -d.;fi)
%if 0%{?rh_dist}
%define dist .rhel%{rh_dist}
%else
%define dist .unknown
%endif
%endif

Summary:        JSON module for Qore
Name:           qore-json-module
Version:        %{mod_ver}
Release:        3.2
License:        MIT
Group:          Development/Languages
URL:            http://qore.org
Source:         https://github.com/qorelanguage/module-json/releases/download/v%{version}/%{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       /usr/bin/env
Requires:       qore-module(abi)%{?_isa} = %{module_api}
BuildRequires:  cmake >= 3.5
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  openssl-devel
BuildRequires:  qore >= 1.12.4
BuildRequires:  qore-devel >= 1.12.4

%description
This package contains the json module for the Qore Programming Language.

JSON is a concise human-readable data serialization format.

%if 0%{?suse_version}
%endif

%prep
%setup -q

%build
export CXXFLAGS="%{?optflags}"
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_BUILD_TYPE=RELWITHDEBINFO -DCMAKE_SKIP_RPATH=1 -DCMAKE_SKIP_INSTALL_RPATH=1 -DCMAKE_SKIP_BUILD_RPATH=1 -DCMAKE_PREFIX_PATH=${_prefix}/lib64/cmake/Qore .
make %{?_smp_mflags}
make %{?_smp_mflags} docs
sed -i 's/#!\/usr\/bin\/env qore/#!\/usr\/bin\/qore/' test/*.qtest examples/*
%if 0%{?suse_version}
#%fdupes -s docs/json
%endif

%install
make DESTDIR=$RPM_BUILD_ROOT install %{?_smp_mflags}
#chmod 0755 /usr/lib64/qore-modules/json-api-1.3.qmod

%files
%defattr(-,root,root,-)
%{module_dir}
%{user_module_dir}
%doc COPYING.LGPL COPYING.MIT README RELEASE-NOTES AUTHORS

%check
qore -l ./json-api-%{module_api}.qmod test/JsonRpcClient.qtest -v
qore -l ./json-api-%{module_api}.qmod test/JsonRpcHandler.qtest -v
qore -l ./json-api-%{module_api}.qmod test/json.qtest -v

%package doc
Summary:        JSON module for Qore
Group:          Development/Languages
BuildArch:      noarch

%description doc
This package contains the HTML documentation and example programs for the Qore
json module.

%files doc
%defattr(-,root,root,-)
%doc docs/json docs/JsonRpcConnection docs/JsonRpcHandler test examples

%changelog
* Sun May 26 2024 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Remove BuildRequirement qore-stdlib after the move of qore-stdlib to qore
* Sat Jul 22 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update %%{module_api} for json api checks
* Fri Jan  6 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.8.2 because of updated qore
  * Updates to allow the module to build with qpp from Qore 1.12.4+
* Tue Jun 14 2022 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.8.1 because of qore-doc requirement
  * eliminated excess whitespace from compact JSON
    serialization (refs qorelanguage/qore#4459)
* Thu Oct 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8 for Qore 1.0.10
  * Fixed module loading
  * Fixed module namespace paths
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8 for Qore 0.9.15
  * added support for new ConnectionProvider
  * fixed parsing JSON numbers with exponents
  * fixed output of noisy floating-point values
  * fixed JsonRpcHandler related to Qore
  * Support QoreValue API
  * https://github.com/qorelanguage/module-json/compare/v1.7...release-0.9.15
- Use cmake macros
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.7:
  * deprecated support for the non-published JSON-RPC 1.1 protocol
  * added support for JSON-RPC 2.0
  * added the JsonRpcConnection user module
  * improved argument error messages with RPC calls in the JsonRpcHandler module (issue 2573)
  * fixed date serialization to use ISO-8601 format (instead of near-ISO-8601 format: issue 2655)
  * parse_json() now ignores UTF-8 and Unicode BOMs at the start of passed JSON string (issue 1398)
  * fixed a bug in request logging in the JsonRpcHandler module (issue 1487)
  * fixed a bug serializing hash keys with embedded quotes (issue 2242)
  * serialize binary values as base64-encoded strings
  * user modules moved to top-level qore module directory from version-specific module directory since they are valid for multiple versions of qore
  * serialize nan, +/-inf as null according to the JSON spec
  * added detection for invalid JSON-RPC calls and added a more user-friendly error message in the JsonRpcHandler module
  * new functions added conforming to Qore's function naming convention, old camel-case functions deprecated
  * JSON tests ported to QUnit
  * Qore 0.8.12 required as a minimum to build
  * JSON output is more compact; less extraneous whitespace is used
- remove 0001-set-64bit-for-other-architectures.patch: upstream
* Mon Apr 30 2018 guillaume.gardet@opensuse.org
- Remove -m32 and -m64 options except for x86* and ppc*
* Mon Dec 22 2014 dimstar@opensuse.org
- Don't start fdupes over docs: it can cause build failures if the
  link is not in the direction expected.
* Mon Aug  4 2014 dvaleev@suse.com
- Set 64bit for powerpc64, aarch64 and s390x
- added patches:
  * 0001-set-64bit-for-other-architectures.patch
* Wed Jul 30 2014 petr@yarpen.cz
- migrated to OBS file layout
